@@ -38,6 +38,8 @@ ADC_GAIN_SETTING_UUID = uuid.UUID("a3c3bb32-9b92-4da1-8ed8-6c09f9c816f8")
 ADC_TISSUE_OFFSET_UUID = uuid.UUID("41069860-159f-49f2-a59d-401783c1ecb4")
 ADC_REF_OFFSET_UUID = uuid.UUID("dc10066c-abf2-42b6-9b94-5e52d1ea9bfc")
 PLATE_BARCODE_UUID = uuid.UUID("cf60afef-a9f0-4bc3-89e9-c665c6bb6941")
+BACKEND_LOG_UUID = uuid.UUID("87533deb-2495-4430-bce7-12fdfc99158e")
+COMPUTER_NAME_HASH = uuid.UUID("fefd0675-35c2-45f6-855a-9500ad3f100d")
 METADATA_UUID_DESCRIPTIONS = {
     HARDWARE_TEST_RECORDING_UUID: "Is Hardware Test Recording",
     START_RECORDING_TIME_INDEX_UUID: "Timepoint of Beginning of Recording",
@@ -66,6 +68,8 @@ METADATA_UUID_DESCRIPTIONS = {
     ADC_TISSUE_OFFSET_UUID: "ADC Tissue Sensor Offset",
     ADC_REF_OFFSET_UUID: "ADC Reference Sensor Offset",
     PLATE_BARCODE_UUID: "Plate Barcode",
+    BACKEND_LOG_UUID: "Backend log file identifier",
+    COMPUTER_NAME_HASH: "SHA512 digest of computer name",
 }
 DATETIME_STR_FORMAT = "%Y-%m-%d %H:%M:%S.%f"
 CENTIMILLISECONDS_PER_SECOND = 1e5
